StorageBackendMemory class

In-memory storage backend

This storage memory uses the RandomAccessBuffer which is an abstraction for managing data in Uint8List as a mean of storage. Data will not be persisted and is lost on close. Data is not stored, is highly volatile and does not survive a page refresh.

Constructors

StorageBackendMemory(Uint8List? bytes, HiveCipher? _cipher, [int initialOffset = 0])
Default constructor for the StorageBackendMemory

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → String?
An in-memory storage has no path
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsCompaction → bool
Whether the database can be compacted
final

Methods

clear() → Future<void>
Clear database
close() → Future<void>
Close database
compact(Iterable<Frame> frames) → Future<void>
Compact database
deleteFromDisk() → Future<void>
Clear database and delete from disk
flush() → Future<void>
Nothing to flush to disk as we act directly in-memory
initialize(TypeRegistry registry, Keystore keystore, bool lazy) → Future<void>
Prepare backend
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readValue(Frame frame) → Future
Read value from backend
toString() → String
A string representation of this object.
inherited
writeFrames(List<Frame> frames) → Future<void>
Write a list of frames to the backend

Operators

operator ==(Object other) → bool
The equality operator.
inherited